<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration
{
    /**
     * Run the migrations.
     */
    public function up(): void
    {
        Schema::create('product_categories', function (Blueprint $table) {
            $table->mediumIncrements('id');

            $table->unsignedMediumInteger('parent_id')->nullable()->index();
            $table->string('parent_slug')->nullable()->index();

            $table->string('name')->index();
            $table->string('slug')->nullable()->index();
            $table->string('icon')->nullable();

            $table->mediumText('description')->nullable();

            $table->boolean('show_in_pos')->index();
            $table->boolean('show_in_purchases')->index();
            $table->boolean('show_in_ecommerce')->index();
            $table->boolean('show_in_manufacturing')->index();
            $table->boolean('show_in_quality')->index();
            $table->boolean('show_in_assets')->index();

            $table->unsignedTinyInteger('priority')->nullable()->index();

            // Aditoria
            $table->timestamps();

            // Index
            $table->unique(['parent_id', 'slug']);

            // Relaciones
            //$table->foreign('parent_id')->references('id')->on('product_categories')->onUpdate('restrict')->onDelete('cascade');
        });

        DB::unprepared("CREATE TRIGGER before_delete_category
            BEFORE DELETE ON product_categories
            FOR EACH ROW
            BEGIN
                -- Verificar si la categoría tiene hijos
                IF (SELECT COUNT(*) FROM product_categories WHERE parent_id = OLD.id) > 0 THEN
                    -- Generar un error para evitar la eliminación
                    SIGNAL SQLSTATE '45000'
                    SET MESSAGE_TEXT = 'No se puede eliminar la categoría porque tiene categorías hijas.';
                END IF;
            END");


        Schema::create('category_properties', function (Blueprint $table) {
            $table->mediumIncrements('id');

            $table->unsignedMediumInteger('category_id')->index();
            $table->unsignedSmallInteger('property_id')->index();

            $table->boolean('is_required'); // Si es obligatorio en esta categoría
            $table->boolean('is_filterable'); // Si se puede usar en filtros

            $table->timestamps();

            // Relaciones
            $table->foreign('category_id')->references('id')->on('product_categories')->onUpdate('restrict')->onDelete('cascade');
            //$table->foreign('property_id')->references('id')->on('product_properties')->onUpdate('restrict')->onDelete('cascade');
        });
    }

    /**
     * Reverse the migrations.
     */
    public function down(): void
    {
        Schema::dropIfExists('product_categories');
        DB::unprepared("DROP TRIGGER IF EXISTS before_delete_category");
        Schema::dropIfExists('category_properties');
    }
};
